This document serves as a way to explicitly give credit to projects which made mcproto possible.

Note that as with any other project, if there was some code that was directly utilized from these projects, it will be
mentioned in `LICENSE-THIRD-PARTY.txt`, not in here. This file isn't meant to serve as a place to disclose used code
and it's licenses, but rather to give proper credit where it is due, and to shout out a few amazing projects that
allowed mcproto to exist in the first place.

- **Minecraft wiki (<https://minecraft.wiki/w/Java_Edition_protocol/>)** (previously `wiki.vg`): An absolutely amazing
  community driven wiki that documents how the minecraft protocol is structured and the changes that occur between the
  protocol versions.
- **PyMine-Net**: The project that was the main inspiration to this project, being a separation of the minecraft
  networking tooling used in PyMine-Server, which is an attempt at implementing a fully working minecraft server purely
  in python. However, this project is no longer maintained, and so mcproto was created to be it's replacement.
- **Mcstatus**: A library that allows for easy fetching of status/query data from minecraft servers, including parsers and
  structures that meaningfully represent the obtained data, but also the logic on how it's actually obtained, some of
  which this project took heavy inspiration from.
- **pyCraft**: A long abandoned project similar to mcproto, which served as an inspiration for various functionalities in
  the library.
- **quarry**: A library providing support for basic interactions with the minecraft protocol, though only up to packet reading.
  Implementation for reading data from specific packets is not included.

To all of these projects, they deserve a massive thank you, for keeping their code/information open-sourced and
available as a source of information, and inspiration freely to anyone.
